@@ -2,7 +2,8 @@
 //
 /****************************************************************************
    Copyright (C) 2013, Arnout Engelen. All rights reserved.
-   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2015, Kjetil Matheussen. (portaudio_probe_thread)
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -57,11 +58,7 @@ qjackctlInterfaceComboBox::qjackctlInterfaceComboBox ( QWidget *pParent )
 	: QComboBox(pParent)
 {
 	QTreeView *pTreeView = new QTreeView(this);
-	QHeaderView *pHeaderView = pTreeView->header();
-	pHeaderView->hide();
-#if QT_VERSION < 0x050000
-	pHeaderView->setResizeMode(QHeaderView::ResizeToContents);
-#endif
+	pTreeView->header()->hide();
 	pTreeView->setRootIsDecorated(false);
 	pTreeView->setAllColumnsShowFocus(true);
 	pTreeView->setSelectionBehavior(QAbstractItemView::SelectRows);
@@ -114,9 +111,139 @@ void qjackctlInterfaceComboBox::addCard (
 }
 
 
+#ifdef CONFIG_COREAUDIO
+
+// borrowed from jackpilot source
+static OSStatus getDeviceUIDFromID( AudioDeviceID id,
+	char *name, UInt32 nsize )
+{
+	UInt32 size = sizeof(CFStringRef);
+	CFStringRef UI;
+	OSStatus res = AudioDeviceGetProperty(id, 0, false,
+		kAudioDevicePropertyDeviceUID, &size, &UI);
+	if (res == noErr) 
+		CFStringGetCString(UI,name,nsize,CFStringGetSystemEncoding());
+	CFRelease(UI);
+	return res;
+}
+
+#endif // CONFIG_COREAUDIO
+
+
+#ifdef CONFIG_PORTAUDIO
+
+#include <QApplication>
+#include <QThread>
+#include <QMutex>
+#include <QMessageBox>
+
+namespace {
+
+class PortAudioProber : public QThread
+{
+public:
+
+	static QStringList getNames(QWidget *pParent)
+	{
+		{
+			QMutexLocker locker(&PortAudioProber::mutex);
+			if (!PortAudioProber::names.isEmpty())
+				return PortAudioProber::names;
+		}
+
+		QMessageBox mbox(QMessageBox::Information, tr("Probing..."),
+			tr("Please wait, PortAudio is probing audio hardware."),
+			QMessageBox::Abort, pParent);
+
+		// Make it impossible to start another PortAudioProber while waiting.
+		mbox.setWindowModality(Qt::WindowModal);
+
+		PortAudioProber *pab = new PortAudioProber;
+
+		pab->start();
+
+		bool bTimedOut = true;
+
+		for (int i = 0; i < 100; ++i) {
+
+			if (mbox.isVisible())
+				QApplication::processEvents();
+
+			QThread::msleep(50);
+
+			if (i == 10) // wait 1/2 second before showing message box
+				mbox.show();
+
+			if (mbox.clickedButton() != NULL) {
+				bTimedOut = false;
+				break;
+			}
+
+			if (pab->isFinished()) {
+				bTimedOut = false;
+				break;
+			}
+		}
+
+		if (bTimedOut) {
+			QMessageBox::warning(pParent, tr("Warning"),
+				tr("Audio hardware probing timed out."));
+		}
+
+		{
+			QMutexLocker locker(&PortAudioProber::mutex);
+			return names;
+		}
+	}
+
+private:
+
+	PortAudioProber() {}
+	~PortAudioProber() {}
+
+	static QMutex mutex;
+	static QStringList names;
+
+	void run()
+	{
+		if (Pa_Initialize() == paNoError) {
+
+			// Fill HostApi info...
+			const PaHostApiIndex iNumHostApi = Pa_GetHostApiCount();
+			QString hostNames[iNumHostApi];
+			for (PaHostApiIndex i = 0; i < iNumHostApi; ++i)
+				hostNames[i] = QString(Pa_GetHostApiInfo(i)->name);
+
+			// Fill device info...
+			const PaDeviceIndex iNumDevice = Pa_GetDeviceCount();
+
+			{
+				QMutexLocker locker(&PortAudioProber::mutex);
+				if (PortAudioProber::names.isEmpty()) {
+					for (PaDeviceIndex i = 0; i < iNumDevice; ++i) {
+						PaDeviceInfo *pDeviceInfo = const_cast<PaDeviceInfo *> (Pa_GetDeviceInfo(i));
+						const QString sName = hostNames[pDeviceInfo->hostApi] + "::" + QString(pDeviceInfo->name);
+						PortAudioProber::names.push_back(sName);
+					}
+				}
+			}
+
+			Pa_Terminate();
+		}
+	}
+};
+
+QMutex PortAudioProber::mutex;
+QStringList PortAudioProber::names;
+
+} // namespace
+
+#endif  // CONFIG_PORTAUDIO
+
+
 void qjackctlInterfaceComboBox::populateModel (void)
 {
-	bool bBlockSignals = QComboBox::blockSignals(true);
+	const bool bBlockSignals = QComboBox::blockSignals(true);
 
 	QComboBox::setUpdatesEnabled(false);
 	QComboBox::setDuplicatesEnabled(false);
@@ -126,15 +253,15 @@ void qjackctlInterfaceComboBox::populateModel (void)
 	// FIXME: Only valid for ALSA, Sun and OSS devices,
 	// for the time being... and also CoreAudio ones too.
 	const QString& sDriver = m_pDriverComboBox->currentText();
-	bool bAlsa      = (sDriver == "alsa");
-	bool bSun       = (sDriver == "sun");
-	bool bOss       = (sDriver == "oss");
+	const bool bAlsa      = (sDriver == "alsa");
+	const bool bSun       = (sDriver == "sun");
+	const bool bOss       = (sDriver == "oss");
 #ifdef CONFIG_COREAUDIO
-	bool bCoreaudio = (sDriver == "coreaudio");
+	const bool bCoreaudio = (sDriver == "coreaudio");
 	std::map<QString, AudioDeviceID> coreaudioIdMap;
 #endif
 #ifdef CONFIG_PORTAUDIO
-	bool bPortaudio = (sDriver == "portaudio");
+	const bool bPortaudio = (sDriver == "portaudio");
 #endif
 	QString sCurName = pLineEdit->text();
 	QString sName, sSubName;
@@ -298,7 +425,7 @@ void qjackctlInterfaceComboBox::populateModel (void)
 							// only show human readable name
 							// humanreadable \t UID
 							sSubName = QString(coreDeviceName);
-							addCard(sSubName, sName);
+							addCard(sName, sSubName);
 							if (sCurName == sName || sCurName == sSubName)
 								iCurCard = iCards;
 							++iCards;
@@ -312,24 +439,13 @@ void qjackctlInterfaceComboBox::populateModel (void)
 #endif 	// CONFIG_COREAUDIO
 #ifdef CONFIG_PORTAUDIO
 	else if (bPortaudio) {
-		if (Pa_Initialize() == paNoError) {
-			// Fill hostapi info...
-			PaHostApiIndex iNumHostApi = Pa_GetHostApiCount();
-			QString *pHostName = new QString[iNumHostApi];
-			for (PaHostApiIndex i = 0; i < iNumHostApi; ++i)
-				pHostName[i] = QString(Pa_GetHostApiInfo(i)->name);
-			// Fill device info...
-			PaDeviceIndex iNumDevice = Pa_GetDeviceCount();
-			PaDeviceInfo **ppDeviceInfo = new PaDeviceInfo * [iNumDevice];
-			for (PaDeviceIndex i = 0; i < iNumDevice; ++i) {
-				ppDeviceInfo[i] = const_cast<PaDeviceInfo *> (Pa_GetDeviceInfo(i));
-				sName = pHostName[ppDeviceInfo[i]->hostApi] + "::" + QString(ppDeviceInfo[i]->name);
-				addCard(sName, QString());
-				if (sCurName == sName)
-					iCurCard = iCards;
-				++iCards;
-			}
-			Pa_Terminate();
+		const QStringList& names = PortAudioProber::getNames(this);
+		const int iCards = names.size();
+		for (int i = 0; i < iCards; ++i) {
+			const QString& sName = names[i];
+			if (sCurName == sName)
+				iCurCard = iCards;
+			addCard(sName, QString());
 		}
 	}
 #endif  // CONFIG_PORTAUDIO
@@ -340,6 +456,11 @@ void qjackctlInterfaceComboBox::populateModel (void)
 	++iCards;
 
 	QTreeView *pTreeView = static_cast<QTreeView *> (QComboBox::view());
+#if QT_VERSION < 0x050000
+	pTreeView->header()->setResizeMode(QHeaderView::ResizeToContents);
+#else
+	pTreeView->header()->resizeSections(QHeaderView::ResizeToContents);
+#endif
 	pTreeView->setMinimumWidth(
 		pTreeView->sizeHint().width() + QComboBox::iconSize().width());
 
