@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -31,6 +31,13 @@
 #include <QFileInfo>
 
 
+#if defined(WIN32)
+#define DEFAULT_DRIVER "portaudio"
+#else
+#define DEFAULT_DRIVER "alsa"
+#endif
+
+
 // Constructor.
 qjackctlSetup::qjackctlSetup (void)
 	: m_settings(QJACKCTL_DOMAIN, QJACKCTL_TITLE)
@@ -90,10 +97,6 @@ void qjackctlSetup::loadSetup (void)
 	sActivePatchbayPath      = m_settings.value("/ActivePatchbayPath").toString();
 	bActivePatchbayReset     = m_settings.value("/ActivePatchbayReset", false).toBool();
 	bQueryDisconnect         = m_settings.value("/QueryDisconnect", true).toBool();
-#ifdef CONFIG_AUTO_REFRESH
-	bAutoRefresh             = m_settings.value("/AutoRefresh", false).toBool();
-	iTimeRefresh             = m_settings.value("/TimeRefresh", 10).toInt();
-#endif
 	bMessagesLog             = m_settings.value("/MessagesLog", false).toBool();
 	sMessagesLogPath         = m_settings.value("/MessagesLogPath", "qjackctl.log").toString();
 	bBezierLines             = m_settings.value("/BezierLines", false).toBool();
@@ -111,17 +114,16 @@ void qjackctlSetup::loadSetup (void)
 	iConnectionsIconSize     = m_settings.value("/ConnectionsIconSize", QJACKCTL_ICON_16X16).toInt();
 	sConnectionsFont         = m_settings.value("/ConnectionsFont").toString();
 	bQueryClose              = m_settings.value("/QueryClose", true).toBool();
+	bQueryShutdown           = m_settings.value("/QueryShutdown", true).toBool();
 	bKeepOnTop               = m_settings.value("/KeepOnTop", false).toBool();
 	bSystemTray              = m_settings.value("/SystemTray", false).toBool();
 	bSystemTrayQueryClose    = m_settings.value("/SystemTrayQueryClose", true).toBool();
-	bStartMinimized          = m_settings.value("/StartMinimized", false).toBool();
-	bDelayedSetup            = m_settings.value("/DelayedSetup", false).toBool();
 	bServerConfig            = m_settings.value("/ServerConfig", true).toBool();
 	sServerConfigName        = m_settings.value("/ServerConfigName", ".jackdrc").toString();
 	bServerConfigTemp        = m_settings.value("/ServerConfigTemp", false).toBool();
-	bQueryShutdown           = m_settings.value("/QueryShutdown", true).toBool();
 	bAlsaSeqEnabled          = m_settings.value("/AlsaSeqEnabled", true).toBool();
 	bDBusEnabled             = m_settings.value("/DBusEnabled", false).toBool();
+	bJackDBusEnabled         = m_settings.value("/JackDBusEnabled", false).toBool();
 	bAliasesEnabled          = m_settings.value("/AliasesEnabled", false).toBool();
 	bAliasesEditing          = m_settings.value("/AliasesEditing", false).toBool();
 	bLeftButtons             = m_settings.value("/LeftButtons", true).toBool();
@@ -207,10 +209,6 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/ActivePatchbayPath",      sActivePatchbayPath);
 	m_settings.setValue("/ActivePatchbayReset",     bActivePatchbayReset);
 	m_settings.setValue("/QueryDisconnect",         bQueryDisconnect);
-#ifdef CONFIG_AUTO_REFRESH
-	m_settings.setValue("/AutoRefresh",             bAutoRefresh);
-	m_settings.setValue("/TimeRefresh",             iTimeRefresh);
-#endif
 	m_settings.setValue("/MessagesLog",             bMessagesLog);
 	m_settings.setValue("/MessagesLogPath",         sMessagesLogPath);
 	m_settings.setValue("/BezierLines",             bBezierLines);
@@ -228,17 +226,16 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/ConnectionsIconSize",     iConnectionsIconSize);
 	m_settings.setValue("/ConnectionsFont",         sConnectionsFont);
 	m_settings.setValue("/QueryClose",              bQueryClose);
+	m_settings.setValue("/QueryShutdown",           bQueryShutdown);
 	m_settings.setValue("/KeepOnTop",               bKeepOnTop);
 	m_settings.setValue("/SystemTray",              bSystemTray);
 	m_settings.setValue("/SystemTrayQueryClose",    bSystemTrayQueryClose);
-	m_settings.setValue("/StartMinimized",          bStartMinimized);
-	m_settings.setValue("/DelayedSetup",            bDelayedSetup);
 	m_settings.setValue("/ServerConfig",            bServerConfig);
 	m_settings.setValue("/ServerConfigName",        sServerConfigName);
 	m_settings.setValue("/ServerConfigTemp",        bServerConfigTemp);
-	m_settings.setValue("/QueryShutdown",           bQueryShutdown);
 	m_settings.setValue("/AlsaSeqEnabled",          bAlsaSeqEnabled);
 	m_settings.setValue("/DBusEnabled",             bDBusEnabled);
+	m_settings.setValue("/JackDBusEnabled",         bJackDBusEnabled);
 	m_settings.setValue("/AliasesEnabled",          bAliasesEnabled);
 	m_settings.setValue("/AliasesEditing",          bAliasesEditing);
 	m_settings.setValue("/LeftButtons",             bLeftButtons);
@@ -363,7 +360,11 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
 	}
 
 	m_settings.beginGroup("/Settings" + sSuffix);
+#if defined(WIN32)
+	preset.sServerPrefix = m_settings.value("/Server", "jackd -S").toString();
+#else
 	preset.sServerPrefix = m_settings.value("/Server", "jackd").toString();
+#endif
 	preset.sServerName  = m_settings.value("/ServerName").toString();
 	preset.bRealtime    = m_settings.value("/Realtime", true).toBool();
 	preset.bSoftMode    = m_settings.value("/SoftMode", false).toBool();
@@ -381,7 +382,7 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
 	preset.iWordLength  = m_settings.value("/WordLength", 16).toInt();
 	preset.iWait        = m_settings.value("/Wait", 21333).toInt();
 	preset.iChan        = m_settings.value("/Chan", 0).toInt();
-	preset.sDriver      = m_settings.value("/Driver", "alsa").toString();
+	preset.sDriver      = m_settings.value("/Driver", DEFAULT_DRIVER).toString();
 	preset.sInterface   = m_settings.value("/Interface").toString();
 	preset.iAudio       = m_settings.value("/Audio", 0).toInt();
 	preset.iDither      = m_settings.value("/Dither", 0).toInt();
@@ -699,17 +700,35 @@ void qjackctlSetup::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 {
 	// Try to restore old form window positioning.
 	if (pWidget) {
+	//	if (bVisible) pWidget->show(); -- force initial exposure?
+		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
+	#if QT_VERSION >= 0x050000
+		const QByteArray& geometry
+			= m_settings.value("/geometry").toByteArray();
+		if (!geometry.isEmpty())
+			pWidget->restoreGeometry(geometry);
+		else
+	#else//--LOAD_OLD_GEOMETRY
 		QPoint wpos;
 		QSize  wsize;
-		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
 		wpos.setX(m_settings.value("/x", -1).toInt());
 		wpos.setY(m_settings.value("/y", -1).toInt());
 		wsize.setWidth(m_settings.value("/width", -1).toInt());
 		wsize.setHeight(m_settings.value("/height", -1).toInt());
-		if (!bVisible) bVisible = m_settings.value("/visible", false).toBool();
+		if (wpos.x() > 0 && wpos.y() > 0)
+			pWidget->move(wpos);
+		if (wsize.width() > 0 && wsize.height() > 0)
+			pWidget->resize(wsize);
+		else
+	#endif
+		pWidget->adjustSize();
+		if (!bVisible)
+			bVisible = m_settings.value("/visible", false).toBool();
+		if (bVisible)
+			pWidget->show();
+		else
+			pWidget->hide();
 		m_settings.endGroup();
-		new qjackctlDelayedSetup(pWidget, wpos, wsize,
-			bVisible && !bStartMinimized, (bDelayedSetup ? 1000 : 0));
 	}
 }
 
@@ -721,53 +740,21 @@ void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 	// only save the form geometry while its up and visible)
 	if (pWidget) {
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
+	#if QT_VERSION >= 0x050000
+		m_settings.setValue("/geometry", pWidget->saveGeometry());
+	#else//--SAVE_OLD_GEOMETRY
 		const QPoint& wpos  = pWidget->pos();
 		const QSize&  wsize = pWidget->size();
-		if (!bVisible) bVisible = pWidget->isVisible();
 		m_settings.setValue("/x", wpos.x());
 		m_settings.setValue("/y", wpos.y());
 		m_settings.setValue("/width", wsize.width());
 		m_settings.setValue("/height", wsize.height());
-		m_settings.setValue("/visible", bVisible && !bStartMinimized);
+	#endif
+		if (!bVisible) bVisible = pWidget->isVisible();
+		m_settings.setValue("/visible", bVisible);
 		m_settings.endGroup();
 	}
 }
 
 
-//---------------------------------------------------------------------------
-// Delayed setup option.
-
-// Delayed widget setup helper class.
-qjackctlDelayedSetup::qjackctlDelayedSetup ( QWidget *pWidget,
-	const QPoint& pos, const QSize& size, bool bVisible, int iDelay )
-	: m_pos(pos), m_size(size)
-{
-	m_pWidget  = pWidget;
-	m_bVisible = bVisible;
-
-	if (iDelay > 0) {
-		QTimer::singleShot(iDelay, this, SLOT(setup()));
-	} else {
-		setup();
-	}
-}
-
-
-void qjackctlDelayedSetup::setup (void)
-{
-	if (m_pWidget) {
-		if (m_pos.x() > 0 && m_pos.y() > 0)
-			m_pWidget->move(m_pos);
-		if (m_size.width() > 0 && m_size.height() > 0)
-			m_pWidget->resize(m_size);
-		else
-			m_pWidget->adjustSize();
-		if (m_bVisible)
-			m_pWidget->show();
-	}
-
-	deleteLater();
-}
-
-
 // end of qjackctlSetup.cpp
