@@ -1,7 +1,7 @@
 // qjackctlSetup.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,10 +24,11 @@
 
 #include "qjackctlConnectAlias.h"
 
-#include <QWidget>
+#include <QStringList>
 
 
 // Forward declarations.
+class QWidget;
 class QComboBox;
 class QSplitter;
 
@@ -140,10 +141,6 @@ public:
 	QString sActivePatchbayPath;
 	bool    bActivePatchbayReset;
 	bool    bQueryDisconnect;
-#ifdef CONFIG_AUTO_REFRESH
-	bool    bAutoRefresh;
-	int     iTimeRefresh;
-#endif
 	bool    bMessagesLog;
 	QString sMessagesLogPath;
 	bool    bBezierLines;
@@ -161,17 +158,16 @@ public:
 	int     iConnectionsIconSize;
 	QString sConnectionsFont;
 	bool    bQueryClose;
+	bool    bQueryShutdown;
 	bool    bKeepOnTop;
 	bool    bSystemTray;
 	bool    bSystemTrayQueryClose;
-	bool    bStartMinimized;
-	bool    bDelayedSetup;
 	bool    bServerConfig;
 	QString sServerConfigName;
 	bool    bServerConfigTemp;
-	bool    bQueryShutdown;
 	bool    bAlsaSeqEnabled;
 	bool    bDBusEnabled;
+	bool    bJackDBusEnabled;
 	bool    bAliasesEnabled;
 	bool    bAliasesEditing;
 	bool    bLeftButtons;
@@ -230,30 +226,6 @@ private:
 };
 
 
-// Delayed widget setup helper class.
-class qjackctlDelayedSetup : public QObject
-{
-	Q_OBJECT
-
-public:
-
-	// Constructor.
-	qjackctlDelayedSetup(QWidget *pWidget,
-		const QPoint& pos, const QSize& size, bool bVisible, int iDelay = 0);
-
-protected slots:
-
-	void setup();
-
-private:
-
-	QWidget *m_pWidget;
-	QPoint   m_pos;
-	QSize    m_size;
-	bool     m_bVisible;
-};
-
-
 #endif  // __qjackctlSetup_h
 
 
