@@ -1,7 +1,7 @@
 // qjackctlSetupForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -55,7 +55,7 @@ protected slots:
 	void deleteCurrentPreset();
 
 	void changeAudio(int);
-	void changeDriver(const QString&);
+	void changeDriver(int);
 
 	void symbolStartupScript();
 	void symbolPostStartupScript();
